Imports System
Imports System.Drawing
Imports System.Collections
Imports System.ComponentModel
Imports System.Windows.Forms
Imports CADImport
Imports CADImport.FaceModule
Imports CADImport.CADImportForms

''' <summary>
''' Represents a form in which the properties of the circle are set 
''' before adding it to the current CAD image.
''' </summary>
Public Class AddCircleForm
    Inherits Form
    ' Events
    Public Event ResizeImageEvent As CADImportEventHandler

    ' Methods
    ''' <summary>
    ''' Initializes a new instance of the <see cref="!:AddEntityDemoApplication.AddCircleForm">AddCircleForm</see> class.
    ''' </summary>
    Public Sub New()
        Me.InitializeComponent()
        Me.InitParams()
    End Sub

    Private Sub addCircleCancel_Click(ByVal sender As Object, ByVal e As EventArgs)
        MyBase.DialogResult = DialogResult.Cancel
        MyBase.Close()
    End Sub

    Private Sub addCircleOK_Click(ByVal sender As Object, ByVal e As EventArgs)
        Me.circle = New CADCircle
        If (Me.setColorDlg.Color.Equals(Color.Black)) Then
            Me.circle.Color = CADConst.clNone
        Else
            Me.circle.Color = Me.setColorDlg.Color
        End If
        Try
            Me.circle.Radius = Convert.ToDouble(Me.tbRadius.Text)
            Me.circle.Point = New DPoint(Convert.ToDouble(Me.tbX.Text), Convert.ToDouble(Me.tbY.Text), Convert.ToDouble(Me.tbZ.Text))
            Me.circle.LineWeight = Convert.ToSingle(Me.cbLineWeight.Text, ApplicationConstants.numInfo)
            Me.cadImage.Converter.GetSection(ConvSection.Entities).AddEntity(Me.circle)
            Me.cadImage.Converter.OnCreate(Me.circle)
            Me.cadImage.Converter.Loads(Me.circle)
            Me.OnResizeImage()
        Catch exception As FormatException
            MessageBox.Show(exception.Message, ApplicationConstants.appconst, MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        End Try
        MyBase.DialogResult = DialogResult.OK
        MyBase.Close()
    End Sub

    ''' <summary>
    ''' Cleans up any resources being used.
    ''' </summary>
    ''' <param name="disposing">A value indicating if both managed and unmanaged resources have to be released (<b>true</b>) or only unmanaged (<b>false</b>). 
    ''' </param>
    Protected Overloads Sub Dispose(ByVal disposing As Boolean)
        If (disposing AndAlso (Not Me.components Is Nothing)) Then
            Me.components.Dispose()
        End If
        MyBase.Dispose(disposing)
    End Sub

#Region " Windows Form Designer generated code "
    ''' <summary>
    ''' Required method for Designer support - do not modify
    ''' the contents of this method with the code editor.
    ''' </summary>
    Private Sub InitializeComponent()
        Me.btnOK = New Button
        Me.btnCancel = New Button
        Me.lbColor = New Label
        Me.tbColor = New TextBox
        Me.btnPickColor = New Button
        Me.tbX = New TextBox
        Me.tbY = New TextBox
        Me.tbZ = New TextBox
        Me.lbX = New Label
        Me.lbY = New Label
        Me.lbZ = New Label
        Me.tbRadius = New TextBox
        Me.lbRad = New Label
        Me.lbWeight = New Label
        Me.cbLineWeight = New ComboBox
        MyBase.SuspendLayout()
        Me.btnOK.FlatStyle = FlatStyle.System
        Me.btnOK.Location = New Point(&H60, &HD8)
        Me.btnOK.Name = "btnOK"
        Me.btnOK.Size = New Size(&H4B, &H19)
        Me.btnOK.TabIndex = 0
        Me.btnOK.Text = "OK"
        AddHandler Me.btnOK.Click, New System.EventHandler(AddressOf Me.addCircleOK_Click)
        Me.btnCancel.FlatStyle = FlatStyle.System
        Me.btnCancel.Location = New Point(&HB9, &HD8)
        Me.btnCancel.Name = "btnCancel"
        Me.btnCancel.Size = New Size(&H4B, &H19)
        Me.btnCancel.TabIndex = 1
        Me.btnCancel.Text = "Cancel"
        AddHandler Me.btnCancel.Click, New System.EventHandler(AddressOf Me.addCircleCancel_Click)
        Me.lbColor.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, &HCC)
        Me.lbColor.Location = New Point(8, &H10)
        Me.lbColor.Name = "lbColor"
        Me.lbColor.Size = New Size(&H38, &H17)
        Me.lbColor.TabIndex = 2
        Me.lbColor.Text = "Color :"
        Me.tbColor.BackColor = Color.Black
        Me.tbColor.Location = New Point(&H60, &H10)
        Me.tbColor.Multiline = True
        Me.tbColor.Name = "tbColor"
        Me.tbColor.Size = New Size(&H4B, &H19)
        Me.tbColor.TabIndex = 3
        Me.tbColor.Text = ""
        Me.btnPickColor.FlatStyle = FlatStyle.System
        Me.btnPickColor.Location = New Point(&HB9, &H10)
        Me.btnPickColor.Name = "btnPickColor"
        Me.btnPickColor.Size = New Size(&H4B, &H19)
        Me.btnPickColor.TabIndex = 4
        Me.btnPickColor.Text = "Pick a color"
        AddHandler Me.btnPickColor.Click, New System.EventHandler(AddressOf Me.pickColorButton_Click)
        Me.tbX.Location = New Point(&HB9, 120)
        Me.tbX.Name = "tbX"
        Me.tbX.Size = New Size(&H4B, 20)
        Me.tbX.TabIndex = 5
        Me.tbX.Text = "100,0"
        Me.tbY.Location = New Point(&HB9, &H98)
        Me.tbY.Name = "tbY"
        Me.tbY.Size = New Size(&H4B, 20)
        Me.tbY.TabIndex = 6
        Me.tbY.Text = "100,0"
        Me.tbZ.Location = New Point(&HB9, &HB8)
        Me.tbZ.Name = "tbZ"
        Me.tbZ.Size = New Size(&H4B, 20)
        Me.tbZ.TabIndex = 7
        Me.tbZ.Text = "0,0"
        Me.lbX.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbX.Location = New Point(8, 120)
        Me.lbX.Name = "lbX"
        Me.lbX.Size = New Size(&HA8, 20)
        Me.lbX.TabIndex = 8
        Me.lbX.Text = "X coordinate of the center :"
        Me.lbY.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbY.Location = New Point(8, &H98)
        Me.lbY.Name = "lbY"
        Me.lbY.Size = New Size(&HA8, 20)
        Me.lbY.TabIndex = 9
        Me.lbY.Text = "Y coordinate of the center :"
        Me.lbZ.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbZ.Location = New Point(8, &HB8)
        Me.lbZ.Name = "lbZ"
        Me.lbZ.Size = New Size(&HA8, 20)
        Me.lbZ.TabIndex = 10
        Me.lbZ.Text = "Z coordinate of the center :"
        Me.tbRadius.Location = New Point(&HB9, &H58)
        Me.tbRadius.Name = "tbRadius"
        Me.tbRadius.Size = New Size(&H4B, 20)
        Me.tbRadius.TabIndex = 11
        Me.tbRadius.Text = "100,0"
        Me.lbRad.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbRad.Location = New Point(8, &H58)
        Me.lbRad.Name = "lbRad"
        Me.lbRad.Size = New Size(&H88, 20)
        Me.lbRad.TabIndex = 12
        Me.lbRad.Text = "Radius of the circle :"
        Me.lbWeight.Font = New Font("Microsoft Sans Serif", 9.75!, FontStyle.Regular, GraphicsUnit.Point, 0)
        Me.lbWeight.Location = New Point(8, &H38)
        Me.lbWeight.Name = "lbWeight"
        Me.lbWeight.Size = New Size(&H58, 20)
        Me.lbWeight.TabIndex = 14
        Me.lbWeight.Text = "Line weight :"
        Me.cbLineWeight.DropDownStyle = ComboBoxStyle.DropDownList
        Me.cbLineWeight.Items.AddRange(New Object() {"0.1", "0.2", "0.3", "0.4", "0.5", "0.6", "0.7", "0.8", "0.9", "1.0", "1.1", "1.2", "1.3", "1.4", "1.5", "1.6", "1.7", "1.8", "1.9", "2.0", "2.1", "2.2", "2.3", "2.4", "2.5", "2.6", "2.7", "2.8", "2.9", "3.0", "3.1", "3.2", "3.3", "3.4", "3.5", "3.6", "3.7", "3.8", "3.9", "4.0", "4.1", "4.2", "4.3", "4.4", "4.5", "4.6", "4.7", "4.8", "4.9", "5.0", "5.1", "5.2", "5.3", "5.4", "5.5", "5.6", "5.7", "5.8", "5.9", "6.0", "6.1", "6.2", "6.3", "6.4", "6.5", "6.6", "6.7", "6.8", "6.9", "7.0", "7.1", "7.2", "7.3", "7.4", "7.5", "7.6", "7.7", "7.8", "7.9", "8.0", "8.1", "8.2", "8.3", "8.4", "8.5", "8.6", "8.7", "8.8", "8.9", "9.0", "9.1", "9.2", "9.3", "9.4", "9.5", "9.6", "9.7", "9.8", "9.9", "10.0"})
        Me.cbLineWeight.Location = New Point(&HB9, &H38)
        Me.cbLineWeight.Name = "cbLineWeight"
        Me.cbLineWeight.Size = New Size(&H4B, &H15)
        Me.cbLineWeight.TabIndex = 15
        Me.AutoScaleBaseSize = New Size(5, 13)
        MyBase.ClientSize = New Size(&H110, &HFB)
        MyBase.Controls.Add(Me.cbLineWeight)
        MyBase.Controls.Add(Me.lbWeight)
        MyBase.Controls.Add(Me.lbRad)
        MyBase.Controls.Add(Me.tbRadius)
        MyBase.Controls.Add(Me.tbZ)
        MyBase.Controls.Add(Me.tbY)
        MyBase.Controls.Add(Me.tbX)
        MyBase.Controls.Add(Me.tbColor)
        MyBase.Controls.Add(Me.lbZ)
        MyBase.Controls.Add(Me.lbY)
        MyBase.Controls.Add(Me.lbX)
        MyBase.Controls.Add(Me.btnPickColor)
        MyBase.Controls.Add(Me.lbColor)
        MyBase.Controls.Add(Me.btnCancel)
        MyBase.Controls.Add(Me.btnOK)
        MyBase.FormBorderStyle = FormBorderStyle.FixedSingle
        MyBase.MinimizeBox = False
        MyBase.Name = "AddCircleForm"
        MyBase.StartPosition = FormStartPosition.CenterParent
        Me.Text = "Add Circle"
        MyBase.ResumeLayout(False)
    End Sub
#End Region

    Private Sub InitParams()
        Me.setColorDlg = New ColorDialog
        Me.cbLineWeight.SelectedItem = ApplicationConstants.onestr
        Me.tbColor.Enabled = False
        MyBase.StartPosition = FormStartPosition.CenterScreen
    End Sub

    Public Sub OnResizeImage()
        'If (Not (ResizeImageEvent Is Nothing)) Then
        RaiseEvent ResizeImageEvent()
        'End If
    End Sub

    Private Sub pickColorButton_Click(ByVal sender As Object, ByVal e As EventArgs)
        If (Me.setColorDlg.ShowDialog = DialogResult.OK) Then
            Me.tbColor.BackColor = Me.setColorDlg.Color
        End If
    End Sub


    ' Properties
    Public Property Image() As CADImage
        Get
            Return Me.cadImage
        End Get
        Set(ByVal value As CADImage)
            Me.cadImage = value
        End Set
    End Property


    ' Fields
    Private btnCancel As Button
    Private btnOK As Button
    Private btnPickColor As Button
    Private cadImage As CADImage
    Private cbLineWeight As ComboBox
    Private circle As CADCircle
    Private components As Container = Nothing
    Private lbColor As Label
    Private lbRad As Label
    Private lbWeight As Label
    Private lbX As Label
    Private lbY As Label
    Private lbZ As Label
    Private setColorDlg As ColorDialog
    Private tbColor As TextBox
    Private tbRadius As TextBox
    Private tbX As TextBox
    Private tbY As TextBox
    Private tbZ As TextBox
End Class



